@@ -1,14 +1,15 @@
-from datetime import datetime
 import time
+from datetime import datetime
 from typing import Any, ClassVar, Dict, Literal, Optional, List, Type, cast
 
 from attrs import define, field
 
-from resoto_plugin_aws.resource.base import AwsResource, AwsApiSpec
-from resoto_plugin_aws.utils import ToDict
-from resotolib.baseresources import BaseStack, BaseAccount  # noqa: F401
-from resotolib.json_bender import Bender, S, Bend, ForallBend
 from resoto_plugin_aws.aws_client import AwsClient
+from resoto_plugin_aws.resource.base import AwsResource, AwsApiSpec, GraphBuilder
+from resoto_plugin_aws.utils import ToDict
+from resotolib.baseresources import BaseStack
+from resotolib.graph import ByNodeId, BySearchCriteria
+from resotolib.json_bender import Bender, S, Bend, ForallBend, F
 from resotolib.types import Json
 
 
@@ -115,14 +116,15 @@ class AwsCloudFormationStack(AwsResource, BaseStack):
             return False
         service = self.api_spec.service
         stack = cast(
-            Json, client.call(service=service, action="describe_stacks", result_name="Stacks", StackName=self.name)[0]
+            Json,
+            client.list(aws_service=service, action="describe-stacks", result_name="Stacks", StackName=self.name)[0],
         )
         stack = self._wait_for_completion(client, stack, service)
 
         try:
             client.call(
-                service="cloudformation",
-                action="update_stack",
+                aws_service="cloudformation",
+                action="update-stack",
                 result_name=None,
                 StackName=self.name,
                 Capabilities=["CAPABILITY_NAMED_IAM"],
@@ -148,7 +150,10 @@ class AwsCloudFormationStack(AwsResource, BaseStack):
                 )
             time.sleep(5)
             stack = cast(
-                Json, client.call(service=service, action="describe_stacks", result_name="Stacks", StackName=self.name)
+                Json,
+                client.list(aws_service=service, action="describe-stacks", result_name="Stacks", StackName=self.name)[
+                    0
+                ],
             )
         return stack
 
@@ -159,9 +164,13 @@ class AwsCloudFormationStack(AwsResource, BaseStack):
         return self._modify_tag(client, key, None, "delete")
 
     def delete_resource(self, client: AwsClient) -> bool:
-        client.call(service=self.api_spec.service, action="delete_stack", result_name=None, StackName=self.name)
+        client.call(aws_service=self.api_spec.service, action="delete-stack", result_name=None, StackName=self.name)
         return True
 
+    @classmethod
+    def called_mutator_apis(cls) -> List[AwsApiSpec]:
+        return [AwsApiSpec("cloudformation", "update-stack"), AwsApiSpec("cloudformation", "delete-stack")]
+
 
 @define(eq=False, slots=False)
 class AwsCloudFormationAutoDeployment:
@@ -200,6 +209,22 @@ class AwsCloudFormationStackSet(AwsResource):
     stack_set_managed_execution: Optional[bool] = field(default=None)
     stack_set_parameters: Optional[Dict[str, Any]] = None
 
+    @classmethod
+    def collect(cls, json: List[Json], builder: GraphBuilder) -> None:
+        def stack_set_instances(ss: AwsCloudFormationStackSet) -> None:
+            for sij in builder.client.list("cloudformation", "list-stack-instances", "Summaries", StackSetName=ss.name):
+                sii = builder.add_node(AwsCloudFormationStackInstanceSummary.from_api(sij))
+                builder.add_edge(ss, node=sii)
+                builder.graph.add_deferred_edge(
+                    ByNodeId(ss.chksum),
+                    BySearchCriteria(f'is(aws_cloudformation_stack) and reported.id="{sii.stack_instance_stack_id}"'),
+                )
+
+        for js in json:
+            stack_set = cls.from_api(js)
+            builder.add_node(stack_set, js)
+            builder.submit_work(stack_set_instances, stack_set)
+
     def _modify_tag(self, client: AwsClient, key: str, value: Optional[str], mode: Literal["update", "delete"]) -> bool:
         tags = dict(self.tags)
         if mode == "delete":
@@ -215,8 +240,8 @@ class AwsCloudFormationStackSet(AwsResource):
 
         try:
             client.call(
-                service="cloudformation",
-                action="update_stack_set",
+                aws_service="cloudformation",
+                action="update-stack-set",
                 result_name=None,
                 StackSetName=self.name,
                 Capabilities=["CAPABILITY_NAMED_IAM"],
@@ -242,12 +267,63 @@ class AwsCloudFormationStackSet(AwsResource):
 
     def delete_resource(self, client: AwsClient) -> bool:
         client.call(
-            service=self.api_spec.service,
-            action="delete_stack_set",
+            aws_service=self.api_spec.service,
+            action="delete-stack-set",
             result_name=None,
             StackSetName=self.name,
         )
         return True
 
+    @classmethod
+    def called_collect_apis(cls) -> List[AwsApiSpec]:
+        return [cls.api_spec, AwsApiSpec("cloudformation", "list-stack-instances")]
 
-resources: List[Type[AwsResource]] = [AwsCloudFormationStack, AwsCloudFormationStackSet]
+    @classmethod
+    def called_mutator_apis(cls) -> List[AwsApiSpec]:
+        return [AwsApiSpec("cloudformation", "update-stack-set"), AwsApiSpec("cloudformation", "delete-stack-set")]
+
+
+def _stack_instance_id(stack: Json) -> str:
+    stack_id = stack.get("StackId", "").rsplit("/", 1)[-1]
+    stack_set_id = stack.get("StackSetId", "")
+    account = stack.get("Account", "")
+    region = stack.get("Region", "")
+    return f"{stack_set_id}/{stack_id}/{account}/{region}"
+
+
+@define(eq=False, slots=False)
+class AwsCloudFormationStackInstanceSummary(AwsResource):
+    # note: resource is collected via AwsCloudFormationStackSet
+    kind: ClassVar[str] = "aws_cloud_formation_stack_instance_summary"
+    mapping: ClassVar[Dict[str, Bender]] = {
+        "id": F(_stack_instance_id),
+        "stack_instance_stack_set_id": S("StackSetId"),
+        "stack_instance_region": S("Region"),
+        "stack_instance_account": S("Account"),
+        "stack_instance_stack_id": S("StackId"),
+        "stack_instance_status": S("Status"),
+        "stack_instance_status_reason": S("StatusReason"),
+        "stack_instance_stack_instance_status": S("StackInstanceStatus", "DetailedStatus"),
+        "stack_instance_organizational_unit_id": S("OrganizationalUnitId"),
+        "stack_instance_drift_status": S("DriftStatus"),
+        "stack_instance_last_drift_check_timestamp": S("LastDriftCheckTimestamp"),
+        "stack_instance_last_operation_id": S("LastOperationId"),
+    }
+    stack_instance_stack_set_id: Optional[str] = field(default=None)
+    stack_instance_region: Optional[str] = field(default=None)
+    stack_instance_account: Optional[str] = field(default=None)
+    stack_instance_stack_id: Optional[str] = field(default=None)
+    stack_instance_status: Optional[str] = field(default=None)
+    stack_instance_status_reason: Optional[str] = field(default=None)
+    stack_instance_stack_instance_status: Optional[str] = field(default=None)
+    stack_instance_organizational_unit_id: Optional[str] = field(default=None)
+    stack_instance_drift_status: Optional[str] = field(default=None)
+    stack_instance_last_drift_check_timestamp: Optional[datetime] = field(default=None)
+    stack_instance_last_operation_id: Optional[str] = field(default=None)
+
+
+resources: List[Type[AwsResource]] = [
+    AwsCloudFormationStack,
+    AwsCloudFormationStackSet,
+    AwsCloudFormationStackInstanceSummary,
+]
