@@ -39,7 +39,7 @@ class AwsPricingProduct:
         "attributes": S("attributes"),
     }
     product_family: Optional[str] = None
-    attributes: Dict[str, str] = field(factory=dict)
+    attributes: Optional[Dict[str, str]] = field(default=None)
     sku: Optional[str] = None
 
 
@@ -138,3 +138,6 @@ class AwsPricingPrice:
             {"Type": "TERM_MATCH", "Field": "location", "Value": pricing_region(region)},
         ]
         return cls.single_price_for(client, "AmazonEC2", search_filter)
+
+
+resources = [AwsPricingPrice]
