@@ -39,5 +39,5 @@ def no_feedback() -> CoreFeedback:
 
 @fixture
 def account_collector(aws_config: AwsConfig, no_feedback: CoreFeedback) -> AwsAccountCollector:
-    account = AwsAccount(id="123")
+    account = AwsAccount(id="test")
     return AwsAccountCollector(aws_config, Cloud(id="aws"), account, ["us-east-1"], no_feedback)
