@@ -1,7 +1,9 @@
 from concurrent.futures import ThreadPoolExecutor
 from typing import Sequence, Tuple, List, Optional
 
-from resoto_plugin_aws.resource.base import ExecutorQueue
+from resoto_plugin_aws.resource.base import ExecutorQueue, AwsRegion, GraphBuilder
+from resoto_plugin_aws.resource.ec2 import AwsEc2InstanceType
+from test import account_collector, builder, aws_client, aws_config, no_feedback  # noqa: F401
 
 
 def check_executor_queue(work: Sequence[int], fail_on_first_exception: bool) -> Tuple[List[int], Optional[Exception]]:
@@ -45,3 +47,16 @@ def test_fail_late() -> None:
     assert work_done == [0, 1, 2, 3, 4, 6, 7, 8, 9]
     assert ex is not None
     assert ex.args[0] == "Abort 5"
+
+
+def test_instance_type_handling(builder: GraphBuilder) -> None:
+    region1 = AwsRegion(id="us-east-1")
+    region2 = AwsRegion(id="us-east-2")
+    it = AwsEc2InstanceType(id="t3.micro")
+    builder.global_instance_types[it.safe_name] = it
+    it1: AwsEc2InstanceType = builder.instance_type(region1, it.safe_name)  # type: ignore
+    assert it1.region() == region1
+    it2: AwsEc2InstanceType = builder.instance_type(region2, it.safe_name)  # type: ignore
+    assert it2.region() == region2
+    assert it1 is not it2
+    assert it1.chksum != it2.chksum
